@@ -879,7 +879,7 @@ gkrellm_load_alertconfig(Alert **ap, gchar *config_line)
 	gchar		config[32], item[CFG_BUFSIZE];
 	gint		n;
 
-	if (!config || !config_line)
+	if (!ap || !config_line)
 		return;
 	if (!*ap)
 		*ap = g_new0(Alert, 1);
