@@ -130,13 +130,25 @@ read_linux_apm_data(void)
 	sscanf(buf, "%*s %*d.%*d %*x %x %x %x %d%% %d %s\n", &ac_line_status,
 			&battery_status, &flag, &percentage, &time, units);
 
-	if ((flag & L_NO_BATTERY) == 0 && battery_status != L_UNKNOWN)
-		sys_apm.battery_is_available = TRUE;
-	else
+	if (   (flag != L_UNKNOWN && (flag & L_NO_BATTERY))
+		|| (battery_status == L_UNKNOWN && ac_line_status == L_UNKNOWN)
+	   )
 		sys_apm.battery_is_available = FALSE;
+	else
+		sys_apm.battery_is_available = TRUE;
+
+	if (ac_line_status != L_UNKNOWN)
+		sys_apm.ac_is_on_line = (ac_line_status == L_ON_LINE) ? TRUE : FALSE;
+	else
+		sys_apm.ac_is_on_line = (battery_status == L_CHARGING) ? FALSE : TRUE;
+
+	if (battery_status != L_UNKNOWN)
+		sys_apm.battery_is_charging =
+					(battery_status == L_CHARGING) ? TRUE : FALSE;
+	else
+		sys_apm.battery_is_charging =
+					(ac_line_status == L_ON_LINE) ? TRUE : FALSE;
 
-	sys_apm.ac_is_on_line = (ac_line_status == L_ON_LINE) ? TRUE : FALSE;
-	sys_apm.battery_is_charging= (battery_status == L_CHARGING) ? TRUE : FALSE;
 	sys_apm.battery_percentage = percentage;
 	sys_apm.battery_time_left = time;
 	if (!strcmp(units, "sec"))
