@@ -1924,14 +1924,6 @@ gkrellm_get_chartdata_hide(ChartData *cd)
 
 /* =================================================================== */
 
-#define CONTROL_BRANCH		"/Control"
-#define CONTROL_ITEM		"/Control/-"
-#define RECALIBRATE_ITEM	"/Control/Auto mode recalibrate"
-#define STICK_ITEM			"/Control/Auto mode sticks at peak value"
-#define SEQUENCE_125_ITEM	"/Control/Sequence.../1 2 5"
-#define SEQUENCE_12357_ITEM	"/Control/Sequence.../1 1.5 2 3 5 7"
-
-
 static void
 chart_config_window_close(GtkWidget *widget, Chart *cp)
 	{
@@ -1962,7 +1954,7 @@ set_resolution_menubar_items_sensitivity(ChartConfig *cf)
 	if (!cf->auto_resolution_item_factory)
 		return;
 	w = gtk_item_factory_get_widget(cf->auto_resolution_item_factory,
-				_(STICK_ITEM));
+				_("/Control/Auto mode sticks at peak value"));
 	if (cf->fixed_grids && cf->auto_grid_resolution)
 		{
 		GTK_CHECK_MENU_ITEM(w)->active = cf->auto_resolution_stick;
@@ -1976,7 +1968,7 @@ set_resolution_menubar_items_sensitivity(ChartConfig *cf)
 		}
 
 	w = gtk_item_factory_get_widget(cf->auto_resolution_item_factory,
-				_(RECALIBRATE_ITEM));
+				_("/Control/Auto mode recalibrate"));
 	if (cf->auto_grid_resolution)
 		gtk_widget_set_sensitive(w, TRUE);
 	else
@@ -2124,14 +2116,19 @@ cb_auto_res_control(Chart *cp, guint option, GtkWidget* widget)
 
 static GtkItemFactoryEntry	auto_res_control_items[] =
     {
-{N_(CONTROL_BRANCH),	NULL,	NULL,				 0,	"<LastBranch>" },
-{N_(CONTROL_ITEM),		NULL,	NULL,				 0,	"<Separator>"},
-{N_(RECALIBRATE_ITEM),	NULL,	cb_auto_res_control, 0,	"<Item>"},
-{N_(STICK_ITEM),		NULL,	cb_auto_res_control, 1,	"<ToggleItem>"},
-{N_(CONTROL_ITEM),		NULL,    NULL,				 0,	"<Separator>"},
-{N_(SEQUENCE_125_ITEM),	NULL,	cb_auto_res_control, 2,	"<RadioItem>"},
-{N_(SEQUENCE_12357_ITEM), NULL,	cb_auto_res_control, 3,	N_(SEQUENCE_125_ITEM)},
-{N_(CONTROL_ITEM),		 NULL,	NULL,				 0,	"<Separator>"},
+{N_("/Control"),	NULL,	NULL,				 0,	"<LastBranch>" },
+{N_("/Control/-"),	NULL,	NULL,				 0,	"<Separator>"},
+{N_("/Control/Auto mode recalibrate"),
+					NULL,	cb_auto_res_control, 0, "<Item>"},
+{N_("/Control/Auto mode sticks at peak value"),
+					NULL,	cb_auto_res_control, 1,	"<ToggleItem>"},
+{N_("/Control/-"),	NULL,    NULL,				 0,	"<Separator>"},
+{N_("/Control/Sequence.../1 2 5"),
+					NULL,	cb_auto_res_control, 2,	"<RadioItem>"},
+{N_("/Control/Sequence.../1 1.5 2 3 5 7"),
+					NULL,	cb_auto_res_control, 3,
+					N_("/Control/Sequence.../1 2 5")},
+{N_("/Control/-"),	 NULL,	NULL,				 0,	"<Separator>"},
     };
 
 static void
@@ -2139,18 +2136,27 @@ auto_resolution_control_menubar(GtkWidget **menubar, Chart *cp)
 	{
 	GtkItemFactory	*item_factory;
 	ChartConfig		*cf = cp->config;
-	gint			n;
+	gint			i, n;
+	static gboolean	translated;
 
 	n = sizeof(auto_res_control_items) / sizeof(GtkItemFactoryEntry);
 	item_factory = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>", NULL);
+	if (!translated)
+		{
+		for(i = 0; i < n; i++)
+			auto_res_control_items[i].path = _(auto_res_control_items[i].path);
+		auto_res_control_items[6].item_type =
+				_(auto_res_control_items[6].item_type);
+		translated = TRUE;
+		}
 	gtk_item_factory_create_items(item_factory, n, auto_res_control_items, cp);
 	cf->auto_resolution_item_factory = item_factory;
 	set_resolution_menubar_items_sensitivity(cf);
 
 	GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget(item_factory,
-			_(SEQUENCE_125_ITEM)))->active = cf->sequence_125;
+		_("/Control/Sequence.../1 2 5")))->active = cf->sequence_125;
 	GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget(item_factory,
-			_(SEQUENCE_12357_ITEM)))->active = !cf->sequence_125;
+		_("/Control/Sequence.../1 1.5 2 3 5 7")))->active = !cf->sequence_125;
 
 	if (menubar)
 		*menubar = gtk_item_factory_get_widget(item_factory, "<main>");
