@@ -21,6 +21,7 @@
 
 #include "gkrellm.h"
 #include "gkrellm_private_proto.h"
+#include "gkrellm_threads.h"
 
 static Monitor	*mon_clock,
 				*mon_cal;
@@ -51,13 +52,25 @@ typedef struct
 
 static gboolean		cal_enable,
 					clock_enable,
-					clock_12hr_seconds,
-					clock_24hr_seconds,
-					clock_24hr_mode;
+					clock_12hr_sec_enable,
+					clock_24hr_sec_enable,
+					clock_24hr_mode,
+                    loop_chime_enable;
 
 static gint			x_clock_seconds,
 					x_clock_no_seconds;
 
+
+static gchar       *hour_chime_command,
+                   *quarter_chime_command;
+
+typedef struct
+    {
+    gchar *command;
+    gint   count;
+    }
+    ChimeData;
+
 static Extents		wday_extents,
 					mday_extents,
 					month_extents,
@@ -83,6 +96,24 @@ string_extents(gchar *string, Extents *ext)
 			&ext->width, &ext->ascent, &ext->descent);
 	}
 
+static void
+chime_func(gpointer data)
+{
+    ChimeData *chime = (ChimeData *)data;
+    int counter;
+
+    if (strlen(chime -> command)) 
+        {
+        if (chime -> count > 12) 
+            chime -> count -= 12;
+
+        for (counter = 0; counter < chime -> count; counter ++)
+            gkrellm_system(chime -> command);
+        }
+    g_free(chime -> command);
+    g_free(chime);
+}
+
 static void
 draw_cal(struct tm *t)
 	{
@@ -125,8 +156,8 @@ draw_clock(struct tm *t, gboolean update_minutes)
 		d_clock->x_off = (w < d_clock->w) ? (d_clock->w - w) / 2 : 0;
 		gkrellm_draw_decal_text(pclock, d_clock, buf, -1);
 		}
-	if (   (!clock_24hr_mode && clock_12hr_seconds)
-		|| (clock_24hr_mode && clock_24hr_seconds)
+	if (   (!clock_24hr_mode && clock_12hr_sec_enable)
+		|| (clock_24hr_mode && clock_24hr_sec_enable)
 	   )
 		{
 		strftime(sec_ampm, sizeof(sec_ampm), "%S", t);	/* seconds 00-59 */
@@ -144,7 +175,8 @@ static void
 update_clock(void)
 	{
 	gboolean	update_minutes = FALSE;
-	static gint	min_prev, hour_prev;
+	static gint	min_prev, hour_prev = -1;
+    ChimeData  *chime;
 
 	if (!GK.second_tick)
 		return;
@@ -154,6 +186,31 @@ update_clock(void)
 		{
 		update_minutes = TRUE;
 		draw_cal(&gkrellm_current_tm);
+        if (   gkrellm_current_tm.tm_hour != hour_prev
+            && hour_prev != -1
+           ) 
+            {
+                if (hour_chime_command && *hour_chime_command) 
+                    {
+                    chime = g_new0(ChimeData, 1);
+                    chime -> command = strdup(hour_chime_command);
+                    chime -> count = loop_chime_enable ? gkrellm_current_tm.tm_hour : 1;
+                    new_thread(chime_func, chime);
+                    }
+            }
+        else
+            {
+                if (   (gkrellm_current_tm.tm_min % 15) == 0
+                    && quarter_chime_command && *quarter_chime_command
+                   ) 
+                    {
+                    
+                    chime = g_new0(ChimeData, 1);
+                    chime -> command = strdup(quarter_chime_command);
+                    chime -> count = 1;
+                    new_thread(chime_func, chime);
+                    }
+            }        
 		}
 	draw_clock(&gkrellm_current_tm, update_minutes);
 	min_prev = gkrellm_current_tm.tm_min;
@@ -248,7 +305,7 @@ static void
 set_seconds_display()
 	{
 	if (   !clock_24hr_mode
-		|| (clock_24hr_mode && clock_24hr_seconds)
+		|| (clock_24hr_mode && clock_24hr_sec_enable)
 	   )
 		{
 		gkrellm_move_decal(pclock, d_clock, x_clock_seconds, d_clock->y);
@@ -321,9 +378,15 @@ save_clock_cal_config(FILE *f)
 				cal_launch.command);
 	fprintf(f, "%s cal_tooltip %s\n", CLOCK_CONFIG_KEYWORD,
 				cal_launch.tooltip_comment);
+	fprintf(f, "%s hour_chime_command %s\n", CLOCK_CONFIG_KEYWORD,
+				hour_chime_command);
+	fprintf(f, "%s quarter_chime_command %s\n", CLOCK_CONFIG_KEYWORD,
+				quarter_chime_command);
+    fprintf(f, "%s loop_chime_enable %d\n", CLOCK_CONFIG_KEYWORD,
+               loop_chime_enable);
 	fprintf(f, "%s clock_options %d %d %d %d\n", CLOCK_CONFIG_KEYWORD,
-				clock_enable, clock_12hr_seconds, clock_24hr_mode, 
-				clock_24hr_seconds);
+				clock_enable, clock_12hr_sec_enable, clock_24hr_mode, 
+				clock_24hr_sec_enable);
 	fprintf(f, "%s cal_options %d\n", CLOCK_CONFIG_KEYWORD,
 				cal_enable);
 	}
@@ -345,9 +408,15 @@ load_clock_cal_config(gchar *arg)
 			cal_launch.command = g_strdup(item);
 		else if (!strcmp(config, "cal_tooltip"))
 			cal_launch.tooltip_comment = g_strdup(item);
+		else if (!strcmp(config, "hour_chime_command"))
+			gkrellm_dup_string(&hour_chime_command, item);
+		else if (!strcmp(config, "quarter_chime_command"))
+			gkrellm_dup_string(&quarter_chime_command, item);
+		else if (!strcmp(config, "loop_chime_enable"))
+			sscanf(item, "%d", &loop_chime_enable);
 		else if (!strcmp(config, "clock_options"))
-			sscanf(item, "%d %d %d %d", &clock_enable, &clock_12hr_seconds,
-					&clock_24hr_mode, &clock_24hr_seconds);
+			sscanf(item, "%d %d %d %d", &clock_enable, &clock_12hr_sec_enable,
+					&clock_24hr_mode, &clock_24hr_sec_enable);
 		else if (!strcmp(config, "cal_options"))
 			sscanf(item, "%d", &cal_enable);
 		}
@@ -358,21 +427,24 @@ static GtkWidget	*cal_launch_entry,
 					*cal_tooltip_entry,
 					*clock_launch_entry,
 					*clock_tooltip_entry,
-					*enable_clk_button,
-					*enable_cal_button,
-					*clk_24hr_button,
-					*clk_24hr_sec_button,
-					*clk_12hr_sec_button;
+                    *hour_chime_entry,
+                    *quarter_chime_entry,
+					*clock_enable_button,
+					*cal_enable_button,
+					*loop_chime_button,
+					*clock_24hr_button,
+					*clock_24hr_sec_button,
+					*clock_12hr_sec_button;
 
 
 static void
 apply_clock_cal_config()
 	{
-	clock_24hr_mode = GTK_TOGGLE_BUTTON (clk_24hr_button)->active;
-	clock_12hr_seconds = GTK_TOGGLE_BUTTON (clk_12hr_sec_button)->active;
-	clock_24hr_seconds = GTK_TOGGLE_BUTTON (clk_24hr_sec_button)->active;
+	clock_24hr_mode = GTK_TOGGLE_BUTTON (clock_24hr_button)->active;
+	clock_12hr_sec_enable = GTK_TOGGLE_BUTTON (clock_12hr_sec_button)->active;
+	clock_24hr_sec_enable = GTK_TOGGLE_BUTTON (clock_24hr_sec_button)->active;
 
-	clock_enable = GTK_TOGGLE_BUTTON (enable_clk_button)->active;
+	clock_enable = GTK_TOGGLE_BUTTON (clock_enable_button)->active;
 	if (clock_enable)
 		{
 		gkrellm_panel_show(pclock);
@@ -384,12 +456,18 @@ apply_clock_cal_config()
 		hide_spacers(mon_clock);
 		}
 
-	cal_enable = GTK_TOGGLE_BUTTON (enable_cal_button)->active;
+	cal_enable = GTK_TOGGLE_BUTTON (cal_enable_button)->active;
 	if (cal_enable)
 		gkrellm_panel_show(pcal);
 	else
 		gkrellm_panel_hide(pcal);
 
+    gkrellm_dup_string(&hour_chime_command,
+			gkrellm_entry_get_text(&hour_chime_entry));
+    gkrellm_dup_string(&quarter_chime_command,
+			gkrellm_entry_get_text(&quarter_chime_entry));
+	loop_chime_enable = GTK_TOGGLE_BUTTON(loop_chime_button)->active;
+
 	gkrellm_apply_launcher(&cal_launch_entry, &cal_tooltip_entry, pcal,
 					&cal_launch, gkrellm_launch_button_cb);
 	gkrellm_apply_launcher(&clock_launch_entry, &clock_tooltip_entry, pclock,
@@ -405,17 +483,17 @@ set_seconds_buttons_sensitivity(gboolean mode_24hr)
 	{
 	if (mode_24hr)
 		{
-		gtk_widget_set_sensitive(clk_24hr_sec_button, TRUE);
-		gtk_widget_set_sensitive(clk_12hr_sec_button, FALSE);
+		gtk_widget_set_sensitive(clock_24hr_sec_button, TRUE);
+		gtk_widget_set_sensitive(clock_12hr_sec_button, FALSE);
 		}
 	else
 		{
-		gtk_widget_set_sensitive(clk_24hr_sec_button, FALSE);
-		gtk_widget_set_sensitive(clk_12hr_sec_button, TRUE);
+		gtk_widget_set_sensitive(clock_24hr_sec_button, FALSE);
+		gtk_widget_set_sensitive(clock_12hr_sec_button, TRUE);
 		}
 	}
 
-static void cb_clk_24hr(GtkToggleButton *tb, gpointer user_data)
+static void cb_clock_24hr(GtkToggleButton *tb, gpointer user_data)
 	{
 	set_seconds_buttons_sensitivity(tb->active);
 	}
@@ -433,26 +511,26 @@ create_clock_tab(GtkWidget *tab_vbox)
 	vbox = gkrellm_create_framed_tab(tabs, _("Options"));
 
 	vbox1 = gkrellm_framed_vbox(vbox, _("Calendar"), 4, FALSE, 0, 2);
-	gkrellm_check_button(vbox1, &enable_cal_button, cal_enable, FALSE, 2,
+	gkrellm_check_button(vbox1, &cal_enable_button, cal_enable, FALSE, 2,
 				_("Enable"));
 
 	vbox1 = gkrellm_framed_vbox_end(vbox, _("Clock"), 4, FALSE, 0, 2);
 
-	gkrellm_check_button(vbox1, &enable_clk_button, clock_enable, 
+	gkrellm_check_button(vbox1, &clock_enable_button, clock_enable, 
 			FALSE, 6, _("Enable"));
 
-	gkrellm_check_button_connected(vbox1, &clk_24hr_button, clock_24hr_mode,
-			FALSE, FALSE, 0, &cb_clk_24hr, 0, 
+	gkrellm_check_button_connected(vbox1, &clock_24hr_button, clock_24hr_mode,
+			FALSE, FALSE, 0, &cb_clock_24hr, 0, 
 			_("Display 24 hour instead of 12 hour time"));
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	gkrellm_check_button(hbox, &clk_12hr_sec_button, clock_12hr_seconds,
+	gkrellm_check_button(hbox, &clock_12hr_sec_button, clock_12hr_sec_enable,
 			FALSE,20, _("Show seconds instead of am/pm in 12 hour time mode"));
 
 	hbox = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
-	gkrellm_check_button(hbox, &clk_24hr_sec_button, clock_24hr_seconds,
+	gkrellm_check_button(hbox, &clock_24hr_sec_button, clock_24hr_sec_enable,
 			FALSE, 20, _("Show seconds in 24 hour time mode"));
 
 	set_seconds_buttons_sensitivity(clock_24hr_mode);
@@ -460,6 +538,22 @@ create_clock_tab(GtkWidget *tab_vbox)
 /* -- Setup tab */
 	vbox = gkrellm_create_framed_tab(tabs, _("Setup"));
 
+	vbox1 = gkrellm_framed_vbox(vbox, _("Clock Chime commands"),
+				4, FALSE, 0, 2);
+	table = gkrellm_launcher_table_new(vbox1, 2);
+
+	gkrellm_config_launcher(table, 0, &hour_chime_entry, NULL,
+			_("Hour"), NULL);
+	gtk_entry_set_text(GTK_ENTRY(hour_chime_entry), hour_chime_command);
+
+	gkrellm_config_launcher(table, 1, &quarter_chime_entry, NULL,
+			_("Quarter hour"), NULL);
+	gtk_entry_set_text(GTK_ENTRY(quarter_chime_entry), quarter_chime_command);
+
+	gkrellm_check_button(vbox, &loop_chime_button, loop_chime_enable,
+			FALSE, 6, _("Loop hour chime command"));
+
+
 	vbox = gkrellm_framed_vbox_end(vbox, _("Launch Commands"), 4, FALSE, 0, 2);
 	table = gkrellm_launcher_table_new(vbox, 2);
 
@@ -498,8 +592,12 @@ init_clock_monitor(void)
 	{
 	clock_enable = TRUE;
     monitor_clock.name = _(monitor_clock.name);
-	clock_12hr_seconds = TRUE;
-	clock_24hr_seconds = TRUE;
+	clock_12hr_sec_enable = TRUE;
+	clock_24hr_sec_enable = TRUE;
+    loop_chime_enable   = FALSE;
+    hour_chime_command = g_strdup("");
+    quarter_chime_command = g_strdup("");
+
 	clock_style_id = gkrellm_add_meter_style(&monitor_clock, CLOCK_STYLE_NAME);
 	mon_clock = &monitor_clock;
 	return &monitor_clock;
@@ -533,6 +631,7 @@ init_cal_monitor(void)
 	{
 	cal_enable = TRUE;
     monitor_cal.name = _(monitor_cal.name);
+
 	cal_style_id = gkrellm_add_meter_style(&monitor_cal, CAL_STYLE_NAME);
 	mon_cal = &monitor_cal;
 	return &monitor_cal;
