@@ -1886,6 +1886,24 @@ gkrellm_config_modified(void)
 	GK.config_modified = TRUE;
 	}
 
+gchar *
+gkrellm_make_data_file_name(gchar *subdir, gchar *name)
+	{
+	gchar	*dir, *path;
+
+	dir = gkrellm_make_config_file_name(NULL, GKRELLM_DATA_DIR);
+	make_home_subdir(dir, &path);
+	if (subdir)
+		{
+		g_free(path);
+		dir = g_strconcat(dir, G_DIR_SEPARATOR_S, subdir, NULL);
+		make_home_subdir(dir, &path);
+		}
+	g_free(dir);
+	if (name)
+		path = g_strconcat(path, G_DIR_SEPARATOR_S, name, NULL);
+	return path;
+	}
 
 gchar *
 gkrellm_make_config_file_name(gchar *dir, gchar *config)
@@ -1966,6 +1984,6 @@ save_user_config(void)
 	fchmod(fileno(f), mode);
 	fclose(f);
 
-	GK.config_modified = 0;
+	GK.config_modified = FALSE;
 	}
 
