@@ -20,6 +20,7 @@
 */
 
 /*
+|  6/30/2002  Mac OS X Darwin code added by Ben Hines <bhines@alumni.ucsd.edu>
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
 |  1/23/2001  Hajimu UMEMOTO improvements with read_freebsd_cpu() and
 |               register_freebsd_cpus().
@@ -43,6 +44,101 @@ gint			n_smp_cpus;
 
 /* ====== System dependent interface ====================================== */
 
+#if defined(__APPLE__)
+/* ----- Darwin  ---------------------------------------------------- */
+#include <mach/mach_init.h>
+#include <mach/mach_host.h>
+
+void read_darwin_cpu()
+{
+		CpuMon	*cpu;
+		gchar *cpuid;
+		GList *list;
+		processor_cpu_load_info_data_t *pinfo;
+		mach_msg_type_number_t info_count;
+		gulong composite_user, composite_nice, composite_sys, composite_idle;
+		int i = 0;
+
+		if (host_processor_info (mach_host_self (),
+						   PROCESSOR_CPU_LOAD_INFO,
+						   &n_cpus,
+						   (processor_info_array_t*)&pinfo,
+						   &info_count)) {
+			return;
+		}
+		
+		
+		composite_user = composite_nice = composite_sys = composite_idle = 0;
+
+		if(n_smp_cpus) i--;		
+        for (list = cpu_mon_list; list; list = list->next, i++) {
+            cpu = (CpuMon *) list->data;
+            cpuid = g_strdup_printf("cpu%d", i);
+            if (strcmp(cpu->name, cpuid)) {
+                g_free(cpuid);
+                continue;
+            }
+            g_free(cpuid);			
+		    cpu->user   = pinfo[i].cpu_ticks [CPU_STATE_USER];
+			cpu->sys    = pinfo[i].cpu_ticks [CPU_STATE_SYSTEM];
+			cpu->idle   = pinfo[i].cpu_ticks [CPU_STATE_IDLE];
+			cpu->nice   = pinfo[i].cpu_ticks [CPU_STATE_NICE];		
+			if(n_smp_cpus)
+			{	
+				composite_user  += pinfo[i].cpu_ticks [CPU_STATE_USER];
+				composite_sys   += pinfo[i].cpu_ticks [CPU_STATE_SYSTEM];
+				composite_idle  += pinfo[i].cpu_ticks [CPU_STATE_IDLE];
+				composite_nice  += pinfo[i].cpu_ticks [CPU_STATE_NICE];
+			}
+		}
+
+		/* dump composite data onto the first element (composite element) */
+		if (n_smp_cpus) {
+			((CpuMon *) cpu_mon_list->data)->user = composite_user;
+			((CpuMon *) cpu_mon_list->data)->nice = composite_nice;
+			((CpuMon *) cpu_mon_list->data)->sys  = composite_sys;
+			((CpuMon *) cpu_mon_list->data)->idle = composite_idle;
+		}
+		
+		vm_deallocate (mach_task_self (), (vm_address_t) pinfo, info_count);
+}
+
+static void register_darwin_cpus() {
+    CpuMon *cpu;
+	processor_cpu_load_info_data_t *pinfo;
+	mach_msg_type_number_t info_count;
+    int i;
+    n_cpus = n_smp_cpus = 0;
+	
+	if (host_processor_info (mach_host_self (),
+						  PROCESSOR_CPU_LOAD_INFO,
+						  &n_cpus,
+						  (processor_info_array_t*)&pinfo,
+						  &info_count)) {
+		return;
+	}
+
+    for(i = 0; i < n_cpus; i++) {
+		cpu = g_new0(CpuMon, 1);
+		cpu->name = g_strdup_printf("cpu%d", i);
+		cpu_mon_list = g_list_append(cpu_mon_list, cpu);
+	}
+
+    if (n_cpus > 1)
+		n_smp_cpus++;
+
+    /* create composite cpu entry and add it at the head of the list */
+    if (n_smp_cpus) {
+        cpu = g_new0(CpuMon, 1);
+        cpu->name = g_strdup("cpu");
+        cpu->is_composite = TRUE;
+        cpu_mon_list = g_list_insert(cpu_mon_list, cpu, 0);
+    }
+
+}
+
+#endif
+
 /* ----- FreeBSD ---------------------------------------------------- */
 
 #if defined(__FreeBSD__) || defined(__OpenBSD__)
@@ -516,7 +612,10 @@ register_glibtop_cpus(void)
 static gint
 setup_cpu_interface(void)
 	{
-#if defined(__FreeBSD__)
+#if defined(__APPLE__)
+	register_darwin_cpus();
+	read_system_cpu_info = read_darwin_cpu;
+#elif defined(__FreeBSD__)
 	register_freebsd_cpus();
 	read_system_cpu_info = read_freebsd_cpu;
 #elif defined(__linux__)
