@@ -20,6 +20,7 @@
 */
 
 /*
+|  6/30/2002  Mac OS X Darwin code added by Ben Hines <bhines@alumni.ucsd.edu>
 | 10/29/2001  Tomas Ogren <stric@cs.umu.se> Solaris patch avoids adding not
 |               found disks to the disk list.
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
@@ -49,6 +50,22 @@ GList		*disk_mon_list;
 
 /* ====== System dependent interface ====================================== */
 
+
+/* ----- Darwin ----------------------------------------------------- */
+
+#if defined(__APPLE__)
+#include <sys/dkstat.h>
+#include <kvm.h>
+static struct nlist nl[] = {
+#define N_DK_NDRIVE	0
+{ "_dk_ndrive" },
+#define N_DK_XFER	1
+{ "_dk_xfer" },
+{ "" }
+};
+extern	kvm_t	*kvmd;
+#endif
+
 /* ----- FreeBSD ----------------------------------------------------- */
 
 #if defined(__FreeBSD__)
@@ -68,15 +85,16 @@ static struct nlist nl[] = {
 };
 
 extern	kvm_t	*kvmd;
-#endif
+#endif // __FreeBSD_version >= 300000
+#endif // FreeBSD
 
+#if defined(__FreeBSD__) || defined(__APPLE__)
 static DiskMon *
 add_disk_device(gint major, gint minor)
 	{
 	return NULL;
 	}
-
-#if __FreeBSD_version < 300000
+#if __FreeBSD_version < 300000 || defined(__APPLE__)
 static void
 read_freebsd_disk()
 	{
@@ -914,7 +932,7 @@ setup_disk_interface(void)
 	{
 	gint	available = FALSE;
 
-#if defined(__FreeBSD__)
+#if defined(__FreeBSD__) || defined(__APPLE__)
 	register_disks(FALSE);
 	read_system_disk_info = read_freebsd_disk;	/* above */
 	available = TRUE;
