@@ -20,6 +20,7 @@
 */
 
 /*
+|  6/30/2002  Mac OS X Darwin code added by Ben Hines <bhines@alumni.ucsd.edu>
 |   2/8/2002  Christian Schroeder <chs@baltic-online.de> patch to avoid
 |               potential Solaris segfault in get_solaris_vfstab_list()
 | 10/29/2001  Darell Tan <dardil@singnet.com.sg> patch adds uid check for
@@ -80,6 +81,7 @@ typedef struct
 
 	gulong		krell_factor;		/* avoid krell math overflow */
 
+	gboolean	busy;
 	gulong		blocks,
 				bfree,
 				bavail,
@@ -111,9 +113,9 @@ static gchar	*eject_tray_command,
 /* ====== System dependent interface ====================================== */
 
 
-/* ----- FreeBSD NetBSD OpenBSD ----------------------------------------- */
+/* ----- FreeBSD NetBSD OpenBSD Darwin ----------------------------------------- */
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 #include <sys/mount.h>
 #include <sys/cdio.h>
 #include <sys/wait.h>
@@ -169,7 +171,7 @@ get_bsd_mounts_list()
 	}
 #endif
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 static void
 eject_bsd_cdrom(gchar *device)
 	{
@@ -182,8 +184,24 @@ eject_bsd_cdrom(gchar *device)
 		close(d);
 		}
 	}
-#endif /* __FreeBSD__ || __NetBSD__ || __OpenBSD__ */
+#endif /* __FreeBSD__ || __NetBSD__ || __OpenBSD__ || __APPLE__ */
 
+#if defined( __APPLE__)
+static void
+set_eject_command(void)
+{
+#if defined(WEXITSTATUS)
+	gint	n;
+
+	n = system("hdiutil info > /dev/null 2>&1");
+	if (WEXITSTATUS(n) == 0)
+	{
+		eject_tray_command = "hdiutil eject %s";
+		close_tray_command = "disktool -o %s";
+	}
+#endif
+}
+#endif /* __APPLE__ */
 
 #if defined(__FreeBSD__)
 static void
@@ -345,7 +363,7 @@ set_eject_command(void)
 /* ----- BSD and Linux ----------------------------------------------- */
 
 #if defined(__linux__) || defined(__FreeBSD__) || defined(__NetBSD__) \
-	|| defined(__OpenBSD__)
+	|| defined(__OpenBSD__) || defined(__APPLE__)
 
 static void
 get_statfs_fsusage(FSmon *fs)
@@ -653,7 +671,7 @@ setup_fs_interface(void)
     {
 	uid = getuid();	/* only real root is allowed to mount/umount always */
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 	get_mountlist = get_bsd_mounts_list;
 	get_fsusage = get_statfs_fsusage;
 	get_fstab_list = get_etc_fstab_list;
@@ -753,7 +771,7 @@ fs_is_mounted(FSmon *fs)
 	for (list = proc_mounts_list; list; list = list->next)
 		{
 		m_mounted = (Mount *) list->data;
-		if (strcmp(m_fs->directory, m_mounted->directory) == 0)
+		if (!strcmp(m_fs->directory, m_mounted->directory))
 			{
 			fs->is_mounted = TRUE;
 			fs->is_nfs_fs = FALSE;
@@ -887,7 +905,7 @@ draw_fs_text_decal(FSmon *fs, gint value)
 		d->x_off = 0;
 		gkrellm_draw_decal_text(fs->panel, d, fs->label, 0);
 		}
-	else
+	else if (!fs->busy)
 		{
 		ts_save = d->text_style;
 		d->text_style = *gkrellm_meter_alt_textstyle(style_id);
@@ -1029,6 +1047,7 @@ mount_command(FSmon *fs)
 			snprintf(cmd, sizeof(cmd), "mount %s", fs->mount.directory);
 		else	/* MT_CUSTOM */
 			snprintf(cmd, sizeof(cmd), "%s", fs->launch_mount.command);
+		fs->blocks = fs->bfree = fs->bavail = fs->bsize = 0;
 		pipe_command(fs, cmd);
 		}
 	force_fs_check = FORCE_REDRAW;	/* An update triggers when pipe closes */
@@ -1066,15 +1085,26 @@ show_monitors_in_drawer(void)
 	gkrellm_thaw_side_frame_packing();
 	}
 
+#if defined (GKRELLM_THREADS)
+static void
+get_fsusage_thread(void *data)
+	{
+	FSmon	*fs = (FSmon *) data;
+
+	(*get_fsusage)(fs);
+	fs->busy = FALSE;
+	}
+#endif
+
 static void
 update_fs(void)
 	{
-	FSmon	*fs;
-	Panel	*p;
-	GList	*list;
-	gulong	l;
-	gint	dx, index, w_scroll, w;
-	gint	fs_check, nfs_check, next_check;
+	FSmon		*fs;
+	Panel		*p;
+	GList		*list;
+	gulong		l;
+	gint		dx, index, w_scroll, w;
+	gboolean	fs_check, nfs_check, force_check, force_draw;
 
 	if (fs_mon_list == NULL)
 		return;
@@ -1112,7 +1142,7 @@ printf("fs update %d nfs %d force %d\n", fs_check, nfs_check, force_fs_check);
 
 	(*get_mountlist)();
 
-	next_check = 0;
+	force_check = force_draw = FALSE;
 
 	for (list = fs_mon_list; list; list = list->next)
 		{
@@ -1122,8 +1152,8 @@ printf("fs update %d nfs %d force %d\n", fs_check, nfs_check, force_fs_check);
 		if (fs_is_mounted(fs))
 			{
 			if (fs->enable_mounting)
-				{	/* Blink it while pipe is open.	*/
-				if (   fs->launch_mount.pipe
+				{	/* Blink it while busy or pipe is open.	*/
+				if (   (fs->launch_mount.pipe || fs->busy)
 					&& fs->md_button->cur_index == D_MISC_FS_MOUNTED
 				   )
 					index = D_MISC_FS_UMOUNTED;
@@ -1132,13 +1162,29 @@ printf("fs update %d nfs %d force %d\n", fs_check, nfs_check, force_fs_check);
 				gkrellm_set_decal_button_index(fs->md_button, index);
 				}
 			else
-				gkrellm_set_decal_button_index(fs->md_button, D_MISC_LED1);
+				{
+				if (fs->busy && fs->md_button->cur_index == D_MISC_LED1)
+					index = D_MISC_LED0;
+				else
+					index = D_MISC_LED1;
+				gkrellm_set_decal_button_index(fs->md_button, index);
+				}
 			if (   force_fs_check == FORCE_UPDATE
 				|| (fs_check && !fs->is_nfs_fs)
 				|| (nfs_check && fs->is_nfs_fs)
 			   )
 				{
+#if defined (GKRELLM_THREADS)
+				if (!fs->is_nfs_fs)
+					(*get_fsusage)(fs);
+				else if (!fs->busy)
+					{
+					fs->busy = TRUE;
+					new_thread(get_fsusage_thread, fs);
+					}
+#else
 				(*get_fsusage)(fs);
+#endif
 				fs->krell_factor = fs->blocks > 2097152 ? 1024 : 1;
 				}			
 			KRELL(p)->full_scale = fs->blocks / fs->krell_factor;
@@ -1147,7 +1193,11 @@ printf("fs update %d nfs %d force %d\n", fs_check, nfs_check, force_fs_check);
 				|| fs->mouse_entered
 			   )
 				l = 0;
-			gkrellm_update_krell(p, KRELL(p), l);
+			if (!fs->busy)
+				gkrellm_update_krell(p, KRELL(p), l);
+			else
+				force_draw = TRUE;
+
 			if (fs->in_drawer && fs->show_if_mounted)
 				gkrellm_panel_show(fs->panel);
 			if (fs->eject_decal)
@@ -1159,7 +1209,7 @@ printf("fs update %d nfs %d force %d\n", fs_check, nfs_check, force_fs_check);
 					{
 					gkrellm_move_decal(p, fs->eject_decal,
 						fs->eject_decal->x + 1 + dx / 4, fs->eject_decal->y);
-					next_check = FORCE_REDRAW;
+					force_draw = TRUE;
 					}
 				}
 			}
@@ -1195,7 +1245,7 @@ printf("fs update %d nfs %d force %d\n", fs_check, nfs_check, force_fs_check);
 				else
 					gkrellm_hide_button(fs->eject_button);
 				if (fs->eject_decal->x != fs->x_eject_button_target)
-					next_check = FORCE_REDRAW;
+					force_draw = TRUE;
 				}
 			}
 		gkrellm_set_button_sensitive(fs->md_button,
@@ -1223,13 +1273,13 @@ printf("fs update %d nfs %d force %d\n", fs_check, nfs_check, force_fs_check);
 					g_string_free(fs->pipe_gstring, 1);
 					fs->pipe_gstring = NULL;
 					}
-				next_check = FORCE_UPDATE;
+				force_check = TRUE;
 				}
 			else
-				next_check = FORCE_REDRAW; 	/* Keep it going */
+				force_draw = TRUE; 	/* Keep it going */
 			}
 		}
-	force_fs_check = next_check;
+	force_fs_check = force_check ? FORCE_UPDATE : force_draw;
 	}
 
 static gint
