@@ -140,7 +140,7 @@ gint	string_position_in_list(GList *list, gchar *s);
 
 gint	isdir(gchar *, gchar *);
 gint	isfile(gchar *);
-gboolean make_home_subdir(gchar *);
+gboolean make_home_subdir(gchar *, gchar **);
 void	dup_home_pathname(gchar **, gchar *, gchar *);
 gchar	*entry_get_alpha_text(GtkWidget **);
 
