@@ -67,7 +67,7 @@ message_window(gchar *title, gchar *message, GtkWidget *widget, gint mainwin)
 	gchar		*s;
 	gint		x, y, w, h, w_main, nlines, dummy;
 
-	if (!message)
+	if (!message || (!GK.debug && GK.no_messages))
 		return;
 	top_win = gkrellm_get_top_window();
 	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
@@ -1967,8 +1967,8 @@ static GtkItemFactoryEntry	menu_items[] =
 	{
 {"/-",				   NULL,	NULL,					0, "<Separator>"},
 {N_("/Configuration"), "F1",	create_config_window, 	0, "<Item>"},
-{N_("/Theme/Prev"),		"p",	cb_load_theme,		THEME_ALT_PREV,	"<Item>"},
-{N_("/Theme/Next"),		"n",	cb_load_theme,		THEME_ALT_NEXT,	"<Item>"},
+{N_("/Theme/Prev"), "Page_Up",	cb_load_theme,	THEME_ALT_PREV,	"<Item>"},
+{N_("/Theme/Next"), "Page_Down", cb_load_theme,	THEME_ALT_NEXT,	"<Item>"},
 {"/-",				   NULL,	NULL,					0, "<Separator>"},
 {N_("/Quit"),		   NULL,	gtk_main_quit,			0, "<Item>"},
 {"/-",				   NULL,	NULL,					0, "<Separator>"},
@@ -1976,10 +1976,10 @@ static GtkItemFactoryEntry	menu_items[] =
 
 static GtkItemFactoryEntry	debug_items[] =
   {
-	{"/-",				    NULL,	NULL,					0, "<Separator>"},
-	{N_("/Theme prev"), 	"u",	cb_load_theme,	THEME_PREV,	"<Item>"},
-	{N_("/Theme next"),		"d",	cb_load_theme,	THEME_NEXT,	"<Item>"},
-	{N_("/Reload Theme"),	"F5",	cb_load_theme,	THEME_RELOAD, "<Item>"}
+{"/-",				    NULL,	NULL,					0, "<Separator>"},
+{N_("/Theme prev"), "<control>Page_Up",	cb_load_theme, THEME_PREV, "<Item>"},
+{N_("/Theme next"), "<control>Page_Down", cb_load_theme, THEME_NEXT, "<Item>"},
+{N_("/Reload Theme"),	"F5",	cb_load_theme,	THEME_RELOAD, "<Item>"}
   };
 
 static GtkItemFactory	*debug_factory;
