@@ -1750,8 +1750,8 @@ make_inet_data_fname(InetMon *in)
 
 	c_sep0 = in->data0_is_range ? '-': '_';
 	c_sep1 = in->data1_is_range ? '-': '_';
-	snprintf(idata_fname, sizeof(idata_fname), "%s/%s/inet_%ld%c%ld_%ld%c%ld",
-		gkrellm_homedir(), inet_data_dir,
+	snprintf(idata_fname, sizeof(idata_fname), "%s%cinet_%ld%c%ld_%ld%c%ld",
+		inet_data_dir, G_DIR_SEPARATOR,
 		in->port0_0, c_sep0, in->port0_1, in->port1_0, c_sep1, in->port1_1);
 	return idata_fname;
 	}
@@ -2386,10 +2386,9 @@ init_inet_monitor(void)
 	style_id = gkrellm_add_chart_style(&monitor_inet, INET_STYLE_NAME);
 	text_format = g_strdup(DEFAULT_TEXT_FORMAT);
 	mon_inet = &monitor_inet;
-	inet_data_dir = g_strdup_printf("%s/inet", GKRELLM_DATA_DIR);
 	if (setup_inet_interface())
-		{
-		make_home_subdir(inet_data_dir);
+		{	/* Make the "data-suffix/inet" directory */
+		inet_data_dir = gkrellm_make_data_file_name("inet", NULL);
 		return &monitor_inet;
 		}
 	return FALSE;
