@@ -413,8 +413,6 @@ gkrellm_draw_decal_text(Panel *p, Decal *d, gchar *s, gint value)
 		ts = &d->text_style;
 		x = d->x_off;
 		y = d->y_baseline;
-//		gdk_draw_pixmap(d->pixmap, GK.draw1_GC, p->bg_pixmap,
-//				d->x, d->y,  0, 0,  d->w, d->h);
 		gkrellm_draw_string(d->pixmap, ts, x, y, s);
 		gdk_draw_rectangle(d->stencil, GK.bit0_GC, TRUE, 0, 0, d->w, d->h);
 		gdk_draw_string(d->stencil, ts->font, GK.bit1_GC, x, y, s);
@@ -852,7 +850,7 @@ gkrellm_create_decal_text(Panel *p, gchar *string, TextStyle *ts,
 
 	/* Setup size and position defaults.  Height is a function of the
 	|  reference string passed in, but width defaults to full chart width
-	|  minus borders unless caller gives a w > 0.  
+	|  minus borders unless w > 0, or w == 0 to use string width.
 	*/
 	d->h = aa + dd + d->text_style.effect;
 	if (style)
@@ -1124,9 +1122,10 @@ gkrellm_destroy_button(DecalButton *b)
 	g_free(b);
 	}
 
-  /* This is called only when cleaning up for a rebuild.  All monitors
-  |  are expected to clean out their decal lists at this time, so I don't
-  |  do any decal freeing here, just clean up the button list.
+  /* This is called only when cleaning up for a rebuild.  Clean out the
+  |  buttons from the button list but leave the decals that make up the
+  |  buttons alone.  The decals are cleaned out in clean_out_panels() or
+  |  by the monitor itself for pre 1.0.x panel management style.
   */
 void
 destroy_decal_button_list(void)
