@@ -33,7 +33,7 @@
 #include <X11/Xmd.h>
 #include <X11/Xatom.h>
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 #include <kvm.h>
 
 kvm_t	*kvmd = NULL;
@@ -362,13 +362,12 @@ static void
 set_or_save_position(gint save)
 	{
 	FILE		*f;
-	gchar		path[128];
+	gchar		*path;
 	gint		x, y;
 	static gint	x_last = -1,
 				y_last = -1;
 
-	snprintf(path, sizeof(path), "%s/%s/startup_position", gkrellm_homedir(),
-				GKRELLM_DATA_DIR);
+	path = gkrellm_make_data_file_name(NULL, "startup_position");
 	if (save)
 		{
 		if (   (x_position != x_last || y_position != y_last)
@@ -388,6 +387,7 @@ set_or_save_position(gint save)
 			{
 			x = y = 0;
 			fscanf(f, "%d %d", &x, &y);
+			fclose(f);
 			if (x >= 0 && x < w_display - 10 && y >= 0 && y < h_display - 25)
 				{
 				x_position = x_last = x;
@@ -396,6 +396,7 @@ set_or_save_position(gint save)
 				}
 			}
 		}
+	g_free(path);
 	}
 
   /* Check if background has changed */
@@ -502,6 +503,9 @@ update_monitors()
 		}
 	check_frame_transparency = FALSE;
 
+	if (GK.minute_tick && GK.config_modified)
+		save_user_config();
+
 	return TRUE;			/* restarts timeout */
 	}
 
@@ -1570,13 +1574,13 @@ check_gkrellm_directories()
 	{
 	gchar	*t, *u;
 
-	if (make_home_subdir(GKRELLM_DIR))
+	if (make_home_subdir(GKRELLM_DIR, NULL))
 		gkrellm_message_window(_("GKrellM Introduction"), _(intro_msg), NULL);
 
-	make_home_subdir(GKRELLM_PLUGINS_DIR);
-	make_home_subdir(GKRELLM_THEMES_DIR);
+	make_home_subdir(GKRELLM_PLUGINS_DIR, NULL);
+	make_home_subdir(GKRELLM_THEMES_DIR, NULL);
 	fix_old_data_dir();
-	make_home_subdir(GKRELLM_DATA_DIR);
+	make_home_subdir(GKRELLM_DATA_DIR, NULL);
 
 	/* If no user_config specified, force a check for host-specific theme
 	*/
@@ -1854,7 +1858,7 @@ main (int argc, char *argv[])
 	gint		i, on_top = 0;
 	gchar		*s, *sm;
 
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 	/* We just ignore error, here.  Even if GKrellM doesn't have
 	|  kmem privilege, it runs with available information.
 	*/
@@ -1931,7 +1935,7 @@ main (int argc, char *argv[])
 
 
 #if !defined(__FreeBSD__) && !defined(__linux__) && !defined(__NetBSD__) \
-	&& !defined(__OpenBSD__) && !defined(__solaris__)
+	&& !defined(__OpenBSD__) && !defined(__solaris__) && !defined(__APPLE__)
 	glibtop_init();
 #endif
 
