@@ -20,6 +20,7 @@
 */
 
 /*
+|  6/30/2002  Mac OS X Darwin code added by Ben Hines <bhines@alumni.ucsd.edu>
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
 |  1/23/2001  Hajimu UMEMOTO added get_bufspace(), improved
 |               read_freebsd_meminfo().
@@ -119,7 +120,89 @@ gint force_meminfo_update();
 
 /* ====== System dependent interface ====================================== */
 
-/* ------- FreeBSD ----------------------------------------------------- */
+/* ------- Darwin ----------------------------------------------------- */
+#if defined(__APPLE__)
+#include <mach/mach_init.h>
+#include <mach/mach_host.h>
+#include <mach/host_info.h>
+#include <mach/mach_error.h>
+#include <sys/types.h>
+#include <dirent.h>
+#include <mach/mach_types.h>
+#include <mach/machine/vm_param.h>
+
+static void
+read_darwin_meminfo()
+{
+	static gint	psize, pshift, first_time_done = 0;
+	vm_statistics_data_t vm_info;
+	mach_msg_type_number_t info_count;
+	kern_return_t	error;
+	static DIR *dirp;
+	struct dirent *dp;
+	off_t swap_total;
+
+	info_count = HOST_VM_INFO_COUNT;
+
+	if (!GK.ten_second_tick && !force_meminfo_update())
+		return;
+	
+	error = host_statistics (mach_host_self (), HOST_VM_INFO, (host_info_t)&vm_info, &info_count);
+	if (error != KERN_SUCCESS)
+	{
+		mach_error("host_info", error);
+		return;
+	}
+
+	if (pshift == 0)
+	{
+		for (psize = getpagesize(); psize > 1; psize >>= 1)
+			pshift++;
+	}
+	
+	mem.x_used = (vm_info.active_count + vm_info.inactive_count + vm_info.wire_count) << pshift;
+	mem.free = vm_info.free_count << pshift;	
+	mem.total = (vm_info.active_count + vm_info.inactive_count + vm_info.free_count + vm_info.wire_count) << pshift;
+	/* Don't know how to get cached or buffers. */
+	mem.buffers = 0;
+	mem.cached = 0;
+	mem.used = mem.x_used; 
+	swap_chart.page_in = vm_info.pageins;
+	swap_chart.page_out = vm_info.pageouts;
+	swap.used = vm_info.pageouts << pshift;
+	
+	/* Figure out total swap. This adds up the size of the swapfiles */
+	if (!first_time_done)
+	{
+		dirp = opendir ("/private/var/vm");
+		if (!dirp)
+			return;
+		++first_time_done;
+	}
+	swap_total = 0;
+	while ((dp = readdir (dirp)) != NULL) {
+		struct stat sb;
+		char fname [MAXNAMLEN];
+		if (strncmp (dp->d_name, "swapfile", 8))
+			continue;
+		strcpy (fname, "/private/var/vm/");
+		strcat (fname, dp->d_name);
+		if (stat (fname, &sb) < 0)
+			continue;
+		swap_total += sb.st_size;
+	}
+	/*  Save overhead, leave it open. where can we close it? */
+	rewinddir(dirp);
+	/*	closedir (dirp); */
+	swap.total = swap_total;
+	
+	/* shared  0 for now, shared is a PITA */
+    mem.shared = 0;	
+}
+
+#endif
+
+/* ------- FreeBSD----------------------------------------------------- */
 
 #if defined(__FreeBSD__)
 #include <osreldate.h>
@@ -338,7 +421,8 @@ swapmode(memint *retavail, memint *retfree)
 
 	return  (int)(((double)used / (double)avail * 100.0) + 0.5);
 	}
-
+	
+	
 static int
 get_bufspace(memint *bufspacep)
 	{
@@ -506,6 +590,7 @@ read_freebsd_meminfo()
 	if (sysctl(oid_vmt, 2, &vmt, &length_vmt, NULL, 0) == 0)
 		mem.shared = vmt.t_rmshr << pshift;
 	get_bufspace(&mem.buffers);
+
 	mem.cached = sum.v_cache_count << pshift;
 	if (swappgsin < 0)
 		{
@@ -532,7 +617,6 @@ read_freebsd_meminfo()
 	}
 #endif
 
-
 /* ------- Linux ----------------------------------------------------- */
 #if defined(__linux__)
 
@@ -820,7 +904,9 @@ read_glibtop_meminfo(void)
 static gint
 setup_meminfo_interface(void)
 	{
-#if defined(__FreeBSD__)
+#if defined(__APPLE__)
+	read_system_meminfo = read_darwin_meminfo;
+#elif defined(__FreeBSD__)
 	read_system_meminfo = read_freebsd_meminfo;
 #elif defined(__linux__)
 	read_system_meminfo = read_proc_meminfo;
@@ -958,7 +1044,7 @@ format_meminfo_data(MeminfoMeter *mm, gchar *buf, gint size)
 		buf += len;
 		}
 	*buf = '\0';
-	return u + 1;		/* A way to know if decal text changed. */
+	return t + u + 1;		/* A way to know if decal text changed. */
 	}
 
 static gint
@@ -1157,7 +1243,8 @@ update_meminfo(void)
 		}
 	if (swap.enabled)
 		{
-		swap.krell_used->full_scale = (gint) (swap.total >> 12);
+		gkrellm_set_krell_full_scale(swap.krell_used,
+					(gint) (swap.total >> 12), 1);
 		u = (gulong)(swap.used >> 12);
 		if (   (swap.label_is_data && mon_in_motion && x_moved)
 			|| swap.mouse_entered
