@@ -119,7 +119,7 @@ static gint	(*is_ISDN_online)();
 
 
 /* -------- FreeBSD / NetBSD / OpenBSD ------------------------------------ */
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 #include <sys/sysctl.h>
 #include <net/if.h>
 #include <net/if_dl.h>
@@ -798,7 +798,7 @@ is_glibtop_ISDN_online(void)
 static gint
 setup_net_interface(void)
     {
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 	read_net_data = read_bsd_net_data;
 	sync_net_interfaces = sync_bsd_net_interfaces;
 	is_ISDN_online = NULL;
