@@ -802,7 +802,9 @@ install_plugin(gchar *plugin_name)
 		dlclose(handle);
 		return NULL;
 		}
+	GK.no_messages = TRUE;		/* Enforce policy */
 	m = (*init_plugin)();
+	GK.no_messages = FALSE;
 	if (m == NULL)
 		{
 		plugin_log(_("\tOoops! plugin returned NULL, aborting\n"), NULL);
