@@ -20,6 +20,7 @@
 */
 
 /*
+|  6/30/2002  Mac OS X Darwin code added by Ben Hines <bhines@alumni.ucsd.edu>
 |  4/22/2001  Solaris code contributed by Daisuke Yabuki <dxy@acm.org>
 |  1/23/2001  Hajimu UMEMOTO added init_freebsd_proc(), improved
 |               read_freebsd_proc()
@@ -62,8 +63,17 @@ void	(*read_system_proc_info)();
 
 /* ====== System dependent interface ====================================== */
 
+
+/* ------- Darwin ----------------------------------------------------- */
+/* Darwin/Apple shares some code with FreeBSD */
+#if defined(__APPLE__)
+#include <sys/sysctl.h>
+#include <sys/user.h>
+#define	PID_MAX		30000
+#endif
+
 /* ------- FreeBSD ----------------------------------------------------- */
-#if defined(__FreeBSD__)
+#if defined(__FreeBSD__) 
 #include <osreldate.h>
 #include <sys/sysctl.h>
 #if __FreeBSD_version >= 400000
@@ -82,6 +92,9 @@ void	(*read_system_proc_info)();
 #include <sys/proc.h>
 #undef KERNEL
 #endif
+#endif
+
+#if defined(__FreeBSD__) || defined(__APPLE__)
 
 #include <kvm.h>
 #include <limits.h>
@@ -131,7 +144,7 @@ init_freebsd_proc()
 static void
 read_freebsd_proc()
 	{
-#if __FreeBSD_version >= 400000
+#if __FreeBSD_version >= 400000 || defined(__APPLE__)
 	static int	oid_proc[] = { CTL_KERN, KERN_PROC, KERN_PROC_ALL };
 #endif
 	double		avenrun;
@@ -188,7 +201,7 @@ read_freebsd_proc()
 			}
 		}
 
-#if __FreeBSD_version >= 400000
+#if __FreeBSD_version >= 400000 || defined(__APPLE__)
 	if (sysctl(oid_proc, 3, NULL, &len, NULL, 0) >= 0)
 		proc.n_processes = len / sizeof(struct kinfo_proc);
 #else
@@ -220,7 +233,6 @@ read_freebsd_proc()
 	}
 #endif
 
-
 /* ------- Linux ----------------------------------------------------- */
 #if defined(__linux__)
 #include <utmp.h>
@@ -437,7 +449,7 @@ read_glibtop_proc(void)
 static gint
 setup_proc_interface(void)
 	{
-#if defined(__FreeBSD__)
+#if defined(__FreeBSD__) || defined(__APPLE__)
 	init_freebsd_proc();
 	read_system_proc_info = read_freebsd_proc;
 #elif defined(__linux__)
