@@ -37,7 +37,7 @@ gulong	(*read_uptime)();
 
 
 /* ----- Pick a system interface ----------------------------------------- */
-#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
 #include <sys/sysctl.h>
 
 static gint
